@@ -21,8 +21,8 @@
 #ifndef KIMAP_SESSIONLOGGER_P_H
 #define KIMAP_SESSIONLOGGER_P_H
 
-#include <QtCore/QObject>
-#include <QtCore/QFile>
+#include <QObject>
+#include <QFile>
 
 namespace KIMAP
 {
@@ -40,6 +40,7 @@ public:
     void disconnectionOccured();
 
 private:
+    Q_DISABLE_COPY(SessionLogger)
     qint64 m_id;
     QFile m_file;
 };
